#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/2/21 13:52
# @Author  : chenjw
# @Site    : 
# @File    : influxdb.py
# @Software: PyCharm Community Edition
# @Desc    :  do what

from influxdb import InfluxDBClient
import logging


class InfluxDB:
    def __init__(self, host, port, username, pwd, database):
        self.host = host
        self.port = port
        self.username = username
        self.pwd = pwd
        self.database = database
        self.client = None

    def getClient(self):
        if self.client is None:
            self.connect()
        return self.client

    def connect(self):
        self.client = InfluxDBClient(self.host, self.port, self.username, self.pwd, self.database)
        self.client.create_database(self.database)

    def close(self):
        try:
            self.client.close()
        except:
            pass

    def query_one(self, value='value', measurement='measurement', where=[]):
        '''
        :param value: key of fields
        :param measurement: measurement
        :param where: conditions
        :return: value of None
        '''
        _query = 'select %s from %s' % (value, measurement)
        if len(where) > 0:
            def combine_where(ss):
                if len(ss) == 1:
                    return ' where ' + ss
                else:
                    tmp = ''
                    for index in range(len(ss)):
                        if index == len(ss) - 1:
                            tmp += ss[index]
                        else:
                            tmp += ss[index] + ' and '
                    return ' where ' + tmp

            _query += combine_where(where)
        _query += ' limit 1'
        result = self.getClient().query(_query)
        try:
            for tmp in result[result.keys()[0]]:
                return tmp[value]
        except:
            return None
        return None

    def recordinfo(self, measurement, date, _time, fields, tags={}):
        '''
        :param client: influxdb client
        :param measurement: key to measure a series of data
        :param date: date like '2018-01-01'
        :param fields:  common like {'value':12.34}
        :param tags: like {'a':'a','b':'b'} use tags to group by data
        :return: nothing ,sometimes print msg if raise Exception
        '''
        try:
            if date is not None:
                self.getClient().write_points([
                    {
                        "measurement": measurement,
                        "tags": tags,
                        "time": "%sT01:00:00Z" % date,
                        "fields": fields
                    }
                ])
            else:
                self.getClient().write_points([
                    {
                        "measurement": measurement,
                        "tags": tags,
                        "time": "%s" % _time,
                        "fields": fields
                    }
                ])
        except Exception as e:
            logging.error('call recordinfo raise exception %s' % e)


if __name__ == '__main__':
    i = InfluxDB('192.168.38.187', 8086, '', '', 'recommend')
    print(i.query_one())
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/23 9:45
# @Author  : chenjw
# @Site    : 
# @File    : setup.py
# @Software: PyCharm Community Edition
# @Desc    :  do what

import codecs
import os
import sys

try:
    from  setuptools import setup
except:
    from distutils.core import setup


def read(fname):
    """

    定义一个read方法，用来读取目录下的长描述

    我们一般是将README文件中的内容读取出来作为长描述，这个会在PyPI中你这个包的页面上展现出来，

    你也可以不用这个方法，自己手动写内容即可，

    PyPI上支持.rst格式的文件。暂不支持.md格式的文件，<BR>.rst文件PyPI会自动把它转为HTML形式显示在你包的信息页面上。

    """

    return codecs.open(os.path.join(os.path.dirname(__file__), fname)).read()


Name = 'ccommon'

PACKAGES = ["ccommon", "db"]

DESCRIPTION = "a package of cc"

LONG_DESCRIPTION = read("README.txt")

KEYWORDS = "cc package"

AUTHOR = "chenjw"

AUTHOR_EMAIL = "781354598@qq.com"

URL = "http://none"

VERSION = "1.1.10"

LICENSE = "MIT"

setup(

    name=Name,

    version=VERSION,

    description=DESCRIPTION,

    long_description=LONG_DESCRIPTION,

    classifiers=[

        'License :: OSI Approved :: MIT License',

        'Programming Language :: Python',

        'Intended Audience :: Developers',

        'Operating System :: OS Independent',

    ],

    keywords=KEYWORDS,

    author=AUTHOR,

    author_email=AUTHOR_EMAIL,

    url=URL,

    license=LICENSE,

    packages=PACKAGES,

    include_package_data=True,

    zip_safe=True,

)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/3/8 18:17
# @Author  : chenjw
# @Site    : 
# @File    : httpSimple.py
# @Software: PyCharm Community Edition
# @Desc    :  do what

from requests.auth import HTTPBasicAuth
import base64
import requests
from ccommon import jsonParse
from bs4 import BeautifulSoup


class HttpSimple():
    def __init__(self, url):
        self.url = url
        self.data = None
        self.headers = None
        self.status_code = 200
        self.basicAuth = None
        self.method = 'get'
        self.rsp = None

    def addData(self, data):
        self.data = data
        return self

    def addDataSingle(self, key, value):
        if self.data is None:
            self.data = {}
        if isinstance(key, str) is True:
            self.headers[key] = value
        return self

    def addHeaders(self, headers):
        if isinstance(headers, dict) is True:
            self.headers = headers
        return self

    def addHeadersSingle(self, key, value):
        if self.headers is None:
            self.headers = {}
        if isinstance(key, str) is True:
            self.data[key] = value
        return self

    def addAuth(self, auth=None, user=None, pwd=None):
        if auth is not None:
            self.basicAuth = auth
        if isinstance(user, str) is True and isinstance(pwd, str) is True:
            pwd = str(base64.b64encode(bytes('%s:%s' % (user, pwd), 'utf-8')), 'utf-8')
            self.basicAuth = HTTPBasicAuth(user, pwd)
        return self

    def addStatusCode(self, status_code):
        if isinstance(status_code, int) is True:
            self.status_code = status_code
        return self

    def addMethod(self, method):
        if isinstance(method, str) is True:
            if method.lower() in ['get', 'post']:
                self.method = method.lower()
        return self

    def run(self):
        if self.method == 'get':
            self.rsp = requests.get(url=self.url, data=self.data, headers=self.headers,auth=self.basicAuth)
        else:
            self.rsp = requests.post(url=self.url, data=self.data, headers=self.headers,auth=self.basicAuth)
        self.checkStatus()
        return self

    def checkStatus(self):
        if self.rsp.status_code != self.status_code:
            raise Exception('[HttpSimple] call url(%s) by method(%s) but status_code is %s' % (
                self.url, self.method, self.rsp.status_code))

    def retJson(self):
        return jsonParse.JsonParse(self.rsp.json())

    def retText(self):
        return self.rsp.text

    def retSoup(self):
        return BeautifulSoup(self.rsp.text, 'html.parser')


if __name__ == '__main__':
    pass
